---
feature_story: FS_28_84_41_40
feature_title: multi-level bootstrap
feature_status: TODO
---

# Background

This feature is a combination of several ideas:

*   TODO: TODO_96_01_13_29: multiple bootstrap stages to instantiate configs.

*   Using Python lang as bootstrap process entry point.

*   Using (mostly) template FS_69_15_45_21 template instantiator.

    This is instead of making copies or symlinks of files from deployed packages. 

There is existing FS_85_33_46_53 process to `bootstrap_env` which will likely be replaced (obsoleted) by this feature.

# Things to address

*   TODO: The Python bootstrap should switch automatically into mode: interpreter already known, interpreter not known yet.

*   TODO: There should be some conventions where to put and how to name generated files.

    Maybe they should be under `gen` dir by their origin, not across multiple dirs by their function.
    They can be referenced from the dir by function using a proxy wrapper (if we talk about scripts).
